#
# spec file for package kiconthemes
#
# Copyright (c) 2019 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define lname   libKF5IconThemes5
%define _tar_path 5.76
# Full KF5 version (e.g. 5.33.0)
%{!?_kf5_version: %global _kf5_version %{version}}
# Last major and minor KF5 version (e.g. 5.33)
%{!?_kf5_bugfix_version: %define _kf5_bugfix_version %(echo %{_kf5_version} | awk -F. '{print $1"."$2}')}
%bcond_without lang
Name:           kiconthemes
Version:        5.76.0
Release:        1.7
Summary:        Icon GUI utilities
License:        LGPL-2.1-or-later AND GPL-2.0-or-later
Group:          System/GUI/KDE
URL:            https://www.kde.org
Source:         https://download.kde.org/stable/frameworks/%{_tar_path}/%{name}-%{version}.tar.xz
%if %{with lang}
Source1:        https://download.kde.org/stable/frameworks/%{_tar_path}/%{name}-%{version}.tar.xz.sig
Source2:        frameworks.keyring
%endif
Source99:        baselibs.conf
BuildRequires:  extra-cmake-modules >= %{_kf5_bugfix_version}
BuildRequires:  fdupes
BuildRequires:  cmake(KF5Archive) >= %{_kf5_bugfix_version}
BuildRequires:  cmake(KF5ConfigWidgets) >= %{_kf5_bugfix_version}
BuildRequires:  cmake(KF5CoreAddons) >= %{_kf5_bugfix_version}
BuildRequires:  kf5-filesystem
BuildRequires:  cmake(KF5I18n) >= %{_kf5_bugfix_version}
BuildRequires:  cmake(KF5ItemViews) >= %{_kf5_bugfix_version}
BuildRequires:  cmake(KF5WidgetsAddons) >= %{_kf5_bugfix_version}
BuildRequires:  cmake(Qt5Core) >= 5.12.0
BuildRequires:  cmake(Qt5DBus) >= 5.12.0
BuildRequires:  cmake(Qt5Svg) >= 5.12.0
BuildRequires:  cmake(Qt5Test) >= 5.12.0
BuildRequires:  cmake(Qt5UiPlugin) >= 5.12.0
BuildRequires:  cmake(Qt5Widgets) >= 5.12.0

%description
This library contains classes to improve the handling of icons
in applications using the KDE Frameworks.

%package -n %{lname}
Summary:        Icon GUI utilities
Group:          System/GUI/KDE
Recommends:     %{lname}-lang = %{version}
%if %pkg_vcmp cmake(Qt5Core) >= 5.12.0
# Used as fallback icon theme starting with Qt 5.12
Recommends:     breeze5-icons
%endif

%description -n %{lname}
This library contains classes to improve the handling of icons
in applications using the KDE Frameworks.

%package devel
Summary:        Icon GUI utilities: Build Environment
Group:          Development/Libraries/KDE
Requires:       %{lname} = %{version}
Requires:       extra-cmake-modules
Requires:       cmake(Qt5Widgets) >= 5.12.0

%description devel
This library contains classes to improve the handling of icons
in applications using the KDE Frameworks. Development files.

%lang_package -n %{lname}

%prep
%setup -q
%autopatch -p1

%build
  %cmake_kf5 -d build
  %cmake_build

%install
  %kf5_makeinstall -C build
  %fdupes %{buildroot}

%if %{with lang}
%find_lang %{name}5
%endif

%post -n %{lname} -p /sbin/ldconfig
%postun -n %{lname} -p /sbin/ldconfig

%if %{with lang}
%files -n %{lname}-lang -f %{name}5.lang
%endif

%files -n %{lname}
%license LICENSES/*
%doc README*
%{_kf5_libdir}/libKF5IconThemes.so.*
%dir %{_kf5_plugindir}/iconengines
%{_kf5_plugindir}/iconengines/KIconEnginePlugin.so
%{_kf5_debugdir}/kiconthemes.categories
%{_kf5_debugdir}/*.renamecategories

%files devel
%{_kf5_bindir}/kiconfinder5
%{_kf5_libdir}/libKF5IconThemes.so
%{_kf5_libdir}/cmake/KF5IconThemes/
%{_kf5_includedir}/*.h
%dir %{_kf5_includedir}/*/
%dir %{_kf5_plugindir}/designer
%{_kf5_plugindir}/designer/kiconthemes5widgets.so
%{_kf5_includedir}/*/
%{_kf5_mkspecsdir}/qt_KIconThemes.pri

%changelog
* Sat Nov  7 2020 christophe@krop.fr
- Update to 5.76.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/kde-frameworks-5.76.0
- Changes since 5.75.0:
  * Keep aspect ration when upscaling
  * If include is define in .h remove it if it's defined in .cpp too (scripted)
* Mon Oct  5 2020 christophe@krop.fr
- Update to 5.75.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/kde-frameworks-5.75.0
- Changes since 5.74.0:
  * Use qDebug and categorized logging
* Sun Sep  6 2020 christophe@krop.fr
- Update to 5.74.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/kde-frameworks-5.74.0
- Changes since 5.73.0:
  * Remove obsolete COPYING files
  * KIconThemes: Convert copyright statements to SPDX expressions
* Sun Aug  2 2020 christophe@krop.fr
- Update to 5.73.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/kde-frameworks-5.73.0
- Changes since 5.72.0:
  * Move forward declaration where it's necessary
  * Use KF-standardized Qt logging categories
  * Use camelcase include. (scripted)
* Sun Jul  5 2020 christophe@krop.fr
- Update to 5.72.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/kde-frameworks-5.72.0
- Changes since 5.71.0:
  * Drop assignment in resetPalette
  * Return QPalette() if we have no custom palette
  * Respect QIcon::fallbackSearchpaths() (kde#405522)
* Sun Jun  7 2020 christophe@krop.fr
- Update to 5.71.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/kde-frameworks-5.71.0
- No code change since 5.70.0
* Sun May  3 2020 christophe@krop.fr
- Update to 5.70.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/kde-frameworks-5.70.0
- Changes since 5.69.0:
  * Add note about porting loadMimeTypeIcon
* Sun Apr  5 2020 christophe@krop.fr
- Update to 5.69.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/kde-frameworks-5.69.0
- No code change since 5.68.0
* Sun Mar  8 2020 christophe@krop.fr
- Update to 5.68.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.68.0.php
- Changes since 5.67.0:
  * Use ecm_qt_install_logging_categories over manual categories file
* Sun Feb  2 2020 christophe@krop.fr
- Replace %%make_jobs with %%cmake_build.
* Sun Feb  2 2020 christophe@krop.fr
- Update to 5.67.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.67.0.php
- No code change since 5.66.0
* Sun Jan  5 2020 christophe@krop.fr
- Update to 5.66.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.66.0.php
- Changes since 5.65.0:
  * Set breeze as default theme when reading from configuration file
  * Qt 5.12 is now required so remove the ifdef
  * Deprecate the top-level IconSize() function
  * Update the obsolete projects.kde.org URL
  * Fix centering scaled icons on high dpi pixmaps
* Sun Dec  8 2019 christophe@krop.fr
- Update to 5.65.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.65.0.php
- Changes since 5.64.0:
  * Deprecate top-level UserIcon method, no longer used
  * Replace for with maths with range for
* Sun Nov  3 2019 christophe@krop.fr
- Update to 5.64.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.64.0.php
- Changes since 5.63.0:
  * Fix usage of the new deprecation macros for assignIconsToContextMenu
  * Deprecate KIconTheme::assignIconsToContextMenu
  * Use ECMGenerateExportHeader to manage deprecated API better
* Sun Oct  6 2019 christophe@krop.fr
- Update to 5.63.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.63.0.php
- Changes since 5.62.0:
  * Deprecate the global [Small|Desktop|Bar]Icon() methods
  * Port away from deprecated QPixmapCache::find method.
* Sat Sep  7 2019 christophe@krop.fr
- Update to 5.62.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.62.0.php
- Changes since 5.61.0:
  * Properly turn real into integer
  * Remove unused includes
  * Add option to build Qt Designer plugin (BUILD_DESIGNERPLUGIN, default ON)
- Replace foo-devel with cmake(KF5Foo) in build requirements
* Wed Aug  7 2019 christophe@krop.fr
- Update to 5.61.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.61.0.php
- Changes since 5.60.0:
  * Restore "Check if group < LastGroup, as KIconEffect doesn't handle UserGroup anyway"
  * Remove explicit use of ECM_KDE_MODULE_DIR, is part of ECM_MODULE_PATH
* Fri Jul 19 2019 wbauer@tmo.at
- Don't lower minimum Qt version anymore, it requires 5.11 now
* Sun Jul 14 2019 lbeltrame@kde.org
- Update to 5.60.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.60.0.php
- Changes since 5.59.0:
  * Install in new logging directory when we use kf5 5.59.0
* Sun Jun  9 2019 lbeltrame@kde.org
- Update to 5.59.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.59.0.php
- No code changes since 5.58.0
* Wed May 15 2019 lbeltrame@kde.org
- Update to 5.58.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.58.0.php
- No code changes since 5.57.0
* Sun Apr 14 2019 lbeltrame@kde.org
- Update to 5.57.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.57.0.php
- Changes since 5.56.0:
  * [kiconthemes] compiles without foreach
  * Fix padding icon that doesn't exactly match the requested size (kde#397106)
* Sun Mar 10 2019 lbeltrame@kde.org
- Update to 5.56.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.56.0.php
- Changes since 5.55.0:
  * It compiles fine without it
  * Port deprecated methods
* Fri Feb 15 2019 alarrosa@suse.com
- Downgrade the Qt version requirement to build with 5.9
* Sun Feb 10 2019 lbeltrame@kde.org
- Update to 5.55.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.55.0.php
- Changes since 5.54.0:
  * Build without D-Bus on Android
  * KIconEffect: Delete copy constructor and assignment operator
  * KIconTheme: Delete copy constructor and assignment operator
  * delete copy constructor and assignment operator of some internal classes
  * Use QStringLiteral
* Mon Jan 14 2019 lbeltrame@kde.org
- Update to 5.54.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.54.0.php
- Changes since 5.53.0:
  * Use for(...:...)
  * Don't check twice if the icon exists from ::availableSizes
  * ksvg2icns : use QStringLiteral()
  * ksvg2icns : use Qt 5.9+ QTemporaryDir API
* Sat Dec 29 2018 wbauer@tmo.at
- Recommend breeze5-icons when building with Qt 5.12.0 or higher,
  it is used as fallback theme starting with Qt 5.12 (boo#920792)
* Sun Dec  9 2018 lbeltrame@kde.org
- Update to 5.53.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.53.0.php
- Changes since 5.52.0:
  * Qt 5.9 is now required
* Sun Nov 11 2018 lbeltrame@kde.org
- Update to 5.52.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.52.0.php
- Changes since 5.51.0:
  * Revert some port to function-object based connect
  * Add a QIconEnginePlugin to allow QIcon deserialization (kde#399989)
  * Port some foreach code to for(...:...)
  * [KIconLoader] Replace heap-allocated QImageReader with stack-allocated one
  * [KIconLoader] Adjust emblem border depending on icon size
  * [KIconLoader] Correct documentation of emblem/overlay order
  * Include own header first
  * Use more function-pointer based connect
  * Use QStringLiteral if a final QString is wanted
  * Use Q_OBJECT with all QObject subclasses (helps debugging introspection)
  * Center icons properly if size doesn't fit (kde#396990)
  * Use new syntax
  * Fixing a copy-paste error
- Dropped patches, now upstream:
  * Fixing-a-copy-paste-error.patch
* Mon Oct 22 2018 wbauer@tmo.at
- Add Fixing-a-copy-paste-error.patch to fix crashes when opening
  the icon dialog (kde#398766)
* Tue Oct 16 2018 lbeltrame@kde.org
- Run spec-cleaner
* Mon Oct 15 2018 lbeltrame@kde.org
- Update to 5.51.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.51.0.php
- Changes since 5.50.0:
  * Start drawing emblems in the bottom-right corner
  * Fix compile with strict compiler flags
* Thu Sep 13 2018 lbeltrame@kde.org
- Update to 5.50.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.50.0.php
- Changes since 5.49.0:
  * Set breeze as fallback icon theme
* Sun Aug 19 2018 christophe@krop.fr
- Update to 5.49.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.49.0.php
- Changes since 5.48.0:
  * Honor BUILD_TESTING
* Mon Jul 16 2018 lbeltrame@kde.org
- Update to 5.48.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.48.0.php
- Changes since 5.47.0:
  * Support choosing .ico files in custom icon file chooser (kde#233201)
  * Support Icon Scale from Icon naming specification 0.13 (kde#365941)
* Tue Jun 12 2018 lbeltrame@kde.org
- Update to 5.47.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.47.0.php
- Changes since 5.46.0:
  * Check if group < LastGroup, as KIconEffect doesn't handle UserGroup anyway
* Sun May 13 2018 lbeltrame@kde.org
- Update to 5.46.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.46.0.php
- Changes since 5.45.0:
  * Fix incorrect version in @since tag
  * Add missing override
* Sat Apr 14 2018 lbeltrame@kde.org
- Update to 5.45.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.45.0.php
- Changes since 5.44.0:
  * Make KIconEngine export comment accurate
  * Fix some warning
  * Fix build on Android
  * Remove not necessary QtCore and co
  * Avoid an asan runtime error
* Mon Mar 12 2018 lbeltrame@kde.org
- Update to 5.44.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.44.0.php
- Changes since 5.43.0:
  * [KIconLoader] Take into account devicePixelRatio for overlays
* Mon Feb 12 2018 lbeltrame@kde.org
- Update to 5.43.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.43.0.php
- Changes since 5.42.0:
  * None
* Tue Jan 16 2018 lbeltrame@kde.org
- Update to 5.42.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.42.0.php
- Changes since 5.41.0:
  * Remove obsolete reviewboardrc file
  * I hope that it fixes build against qt5.7
  * not necessary to add to list of cpp file
  * Minor optimization. Remove unused variable. Optimize loop.
  * Pedantic
  * Port to new connect api
  * Use QStringLiteral/QLatin1Char
  * Fix some clazy wrning
  * Remove extra ';'
* Sun Dec 17 2017 lbeltrame@kde.org
- Update to 5.41.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.41.0.php
- Changes since 5.40.0:
  * We depend against 5.7
* Mon Nov 13 2017 lbeltrame@kde.org
- Update to 5.40.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.40.0.php
- Changes since 5.39.0:
  * Add .arcconfig
* Mon Oct 23 2017 lbeltrame@kde.org
- Update to 5.39.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.39.0.php
- Changes since 5.38.0:
  * add a method to reset the custom palette
  * use qApp->palette() when no custom one is set
  * allocate the proper buffer size
  * allow to set a custom palette instead of colorSets
  * expose the colorset for the stylesheet
* Tue Sep 12 2017 lbeltrame@kde.org
- Update to 5.38.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.38.0.php
- Changes since 5.37.0:
  * Do not leak symbols of pimpl classes, protect with Q_DECL_HIDDEN
* Sat Aug 12 2017 christophe@krop.fr
- Update to 5.37.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.37.0.php
- Changes since 5.36.0 :
  * None
* Wed Jul 12 2017 lbeltrame@kde.org
- Update to 5.36.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.36.0.php
- Changes since 5.35.0:
  * More details about deploying icon themes on Mac & MSWin
  * [FEATURE] Option to build & install QCH file with the public API dox
  * Change panel icon size default to 48.
* Sun Jun 11 2017 lbeltrame@kde.org
- Update to 5.35.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.35.0.php
- Changes since 5.34.0:
  * tests: be safer when using QDir::removeRecursively() on teardown
  * API dox: note CamelCase includes by @class tag with more classes
* Thu May 18 2017 lbeltrame@kde.org
- Add GPL-2.0 to the license to match tools (as per legal review)
* Mon May 15 2017 fabian@ritter-vogt.de
- Update to 5.34.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.34.0.php
- Changes since 5.33.0:
  * Don't even try to create icons with empty sizes
* Sat Apr 15 2017 lbeltrame@kde.org
- Update to 5.33.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.33.0.php
- Changes since 5.32.0:
  * Upgrade ECM and KF5 version requirements for 5.33.0 release.
  * Upgrade KF5 version to 5.33.0.
* Sun Mar 19 2017 lbeltrame@kde.org
- Update to 5.32.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.32.0.php
- Changes since 5.31.0:
  * Commit translations from l10n-kf5
  * Upgrade ECM and KF5 version requirements for 5.32.0 release.
  * Fix APIDOX as raised by clang's -Wdocumentation
  * Upgrade KF5 version to 5.32.0.
* Thu Feb  9 2017 hrvoje.senjan@gmail.com
- Update to 5.31.0
  * For more details please see:
    https://www.kde.org/announcements/kde-frameworks-5.31.0.php
* Sun Jan  8 2017 hrvoje.senjan@gmail.com
- Update to 5.30.0
  * For more details please see:
    https://www.kde.org/announcements/kde-frameworks-5.30.0.php
* Sun Dec  4 2016 hrvoje.senjan@gmail.com
- Update to 5.29.0
  * Allow showing icons from all categories (kde#216653)
  * For more details please see:
    https://www.kde.org/announcements/kde-frameworks-5.29.0.php
* Sat Nov  5 2016 hrvoje.senjan@gmail.com
- Update to 5.28.0
  * Support non integer scale factors in kiconengine (kde#366451)
  * For more details please see:
    https://www.kde.org/announcements/kde-frameworks-5.28.0.php
* Sun Oct  2 2016 hrvoje.senjan@gmail.com
- Update to 5.27.0
  * For more details please see:
    https://www.kde.org/announcements/kde-frameworks-5.27.0.php
* Tue Sep  6 2016 hrvoje.senjan@gmail.com
- Update to 5.26.0
  * For more details please see:
    https://www.kde.org/announcements/kde-frameworks-5.26.0.php
* Sun Aug  7 2016 hrvoje.senjan@gmail.com
- Update to 5.25.0
  * Qt >= 5.5 is now required
  * Greatly improve the performance of makeCacheKey, as it is
    a critical code path in icon lookup
  * KIconLoader: reduce number of lookups when doing fallbacks
  * KIconLoader: massive speed improvement for
    loading unavailable icons
  * Do not clear search line when switching category
  * KIconEngine: Fix QIcon::hasThemeIcon always returning true
    (kde#365130)
  * For more details please see:
    https://www.kde.org/announcements/kde-frameworks-5.25.0.php
- Drop upstreamed 0001-KIconEngine-Fix-QIcon-hasThemeIcon-always-returning-.patch
* Fri Jul 15 2016 hrvoje.senjan@gmail.com
- Added 0001-KIconEngine-Fix-QIcon-hasThemeIcon-always-returning-.patch
  from upstream
* Wed Jul  6 2016 hrvoje.senjan@gmail.com
- Update to 5.24.0
  * Add support for loading and using an icontheme
    in a RCC file automatically
  * Document icon theme deployment on MacOS and Windows,
    see https://api.kde.org/frameworks/kiconthemes/html/index.html
  * For more details please see:
    https://www.kde.org/announcements/kde-frameworks-5.24.0.php
* Mon Jun  6 2016 hrvoje.senjan@gmail.com
- Update to 5.23.0
  * Don't make KIconThemes depend on Oxygen (kde#360664)
  * Selected state concept for icons
  * Use system colors for monochrome icons
  * For more details please see:
    https://www.kde.org/announcements/kde-frameworks-5.23.0.php
* Sat May  7 2016 hrvoje.senjan@gmail.com
- Update to 5.22.0 (boo#980066)
  * Use appropriate container for internal pointer array
  * Add opportunity to reduce unneeded disk accesses,
    introduces KDE-Extensions
  * Save some disk accesses
  * For more details please see:
    https://www.kde.org/announcements/kde-frameworks-5.22.0.php
* Mon Apr  4 2016 hrvoje.senjan@gmail.com
- Update to 5.21.0 (boo#974793)
  * Upgrade Qt version requirement to 5.4.0
  * For more details please see:
    https://www.kde.org/announcements/kde-frameworks-5.21.0.php
* Fri Mar 18 2016 wbauer@tmo.at
- Drop breeze.diff: it caused an incorrect fallback to breeze
  instead of hicolor when a different icon theme is configured, and
  has been reverted (and even rejected in a second try) upstream
  (kde#356064, kde#360664)
* Sun Mar  6 2016 hrvoje.senjan@gmail.com
- Update to 5.20.0 (boo#970856)
  * Make sure variable is being initialized
  * For more details please see:
    https://www.kde.org/announcements/kde-frameworks-5.20.0.php
* Sat Feb  6 2016 hrvoje.senjan@gmail.com
- Update to 5.19.0 (boo#967668)
  * For more details please see:
    https://www.kde.org/announcements/kde-frameworks-5.19.0.php
* Sat Jan  2 2016 hrvoje.senjan@gmail.com
- Update to 5.18.0
  * For more details please see:
    https://www.kde.org/announcements/kde-frameworks-5.18.0.php
* Thu Dec 10 2015 hrvoje.senjan@gmail.com
- Update to 5.17.0
  * For more details please see:
    https://www.kde.org/announcements/kde-frameworks-5.17.0.php
* Fri Nov 20 2015 hrvoje.senjan@gmail.com
- Added breeze.diff: default to breeze icon theme in order to avoid
  setup with mixed icons (half oxygen, half breeze)
* Sun Nov  8 2015 hrvoje.senjan@gmail.com
- Update to 5.16.0 (boo#955067)
  * kiconthemes now support themes embedded in qt resources inside
    the :/icons prefix like Qt does itself for QIcon::fromTheme
  * Add missing required dependencies
  * For more details please see:
    https://www.kde.org/announcements/kde-frameworks-5.16.0.php
* Mon Oct  5 2015 hrvoje.senjan@gmail.com
- Update to 5.15.0
  * For more details please see:
    https://www.kde.org/announcements/kde-frameworks-5.15.0.php
* Tue Sep  8 2015 hrvoje.senjan@gmail.com
- Update to 5.14.0
  * KIconLoader: fix reconfigure() forgetting about inherited
    themes and app dirs
  * Adhere better to the icon loading spec
  * For more details please see:
    https://www.kde.org/announcements/kde-frameworks-5.14.0.php
* Tue Aug  4 2015 hrvoje.senjan@gmail.com
- Update to 5.13.0
  * The Qt version requirement has been bumped from 5.2 to 5.3
  * Debug output has been ported to categorized output, for less
    noise by default
  * Docbook documentation has been reviewed and updated
  * Remove temporary string allocations.
  * Remove Theme tree debug entry
  * For more details please see:
    https://www.kde.org/announcements/kde-frameworks-5.13.0.php
* Sun Jul  5 2015 hrvoje.senjan@gmail.com
- Update to 5.12.0
  * Don't try to paint the icon if the size is invalid
  * For more details please see:
    https://www.kde.org/announcements/kde-frameworks-5.12.0.php
* Sun Jun  7 2015 hrvoje.senjan@gmail.com
- Update to 5.11.0
  * Optimize KIconEngine::availableSizes()
  * For more details please see:
    https://www.kde.org/announcements/kde-frameworks-5.11.0.php
* Sun May  3 2015 hrvoje.senjan@gmail.com
- Update to 5.10.0
  * For more details please see:
    https://www.kde.org/announcements/kde-frameworks-5.10.0.php
* Sat Apr  4 2015 hrvoje.senjan@gmail.com
- Update to 5.9.0
  * KIconDialog can now be shown using the regular
    QDialog show() and exec() methods
  * Fix KIconEngine::paint to handle different devicePixelRatios
  * For more details please see:
    https://www.kde.org/announcements/kde-frameworks-5.9.0.php
- Drop no longer needed Requires of the devel subpackage:
  kconfigwidgets-devel, ki18n-devel, kitemviews-devel and
  kwidgetsaddons-devel
* Sat Mar  7 2015 hrvoje.senjan@gmail.com
- Update to 5.8.0
  * Fix QIcon::fromTheme(xxx, someFallback) would not
    return the fallback
  * For more details please see:
    https://www.kde.org/announcements/kde-frameworks-5.8.0.php
* Sun Feb  8 2015 hrvoje.senjan@gmail.com
- Update to 5.7.0
  * For more details please see:
    https://www.kde.org/announcements/kde-frameworks-5.7.0.php
* Sat Jan  3 2015 hrvoje.senjan@gmail.com
- Update to 5.6.0
  * For more details please see:
    https://www.kde.org/announcements/kde-frameworks-5.6.0.php
* Sat Dec  6 2014 hrvoje.senjan@gmail.com
- Update to 5.5.0
  * For more details please see:
    https://www.kde.org/announcements/kde-frameworks-5.5.0.php
* Sun Nov  2 2014 hrvoje.senjan@gmail.com
- Update to 5.4.0
  * For more details please see:
    https://www.kde.org/announcements/kde-frameworks-5.4.0.php
* Sat Oct  4 2014 hrvoje.senjan@gmail.com
- Update to 5.3.0
  * For more details please see:
    https://www.kde.org/announcements/kde-frameworks-5.3.0.php
* Tue Sep  9 2014 hrvoje.senjan@gmail.com
- Update to 5.2.0
  * For more details please see:
    http://kde.org/announcements/kde-frameworks-5.2.php
* Sat Aug  2 2014 hrvoje.senjan@gmail.com
- Update to 5.1.0
  * For more details please see:
    http://www.kde.org/announcements/kde-frameworks-5.1.php
* Fri Jul 11 2014 hrvoje.senjan@gmail.com
- Define kf5_version within package
* Tue Jul  1 2014 hrvoje.senjan@gmail.com
- Update to 5.0.0
  * Final release of KDE Frameworks 5
  * API improvements and cleanups
  * Buildsystem fixes
  * For more details please see:
    http://www.kde.org/announcements/kde-frameworks-5.0.php
- Drop 0001-Allow-passing-custom-theme-base-path-together-with-c.patch,
  merged upstream
* Sun Jun  1 2014 hrvoje.senjan@gmail.com
- Update to 4.100.0
  * API improvements and cleanups
  * Buildsystem fixes
  * For more details please see:
    http://www.kde.org/announcements/announce-frameworks5-beta3.php
- Add baselibs.conf
- Added 0001-Allow-passing-custom-theme-base-path-together-with-c.patch:
  fixes non-SNI Qt icons in systray
* Sun May  4 2014 hrvoje.senjan@gmail.com
- Update to 4.99.0
  * API improvements and cleanups
  * Buildsystem fixes
  * For more details please see:
    http://www.kde.org/announcements/announce-frameworks5-beta2.php
* Sat Mar 29 2014 hrvoje.senjan@gmail.com
- Update to 4.98.0
  * API improvements and cleanups
  * Buildsystem fixes
  * For more details please see:
    http://www.kde.org/announcements/announce-frameworks5-beta1.php
* Tue Mar  4 2014 hrvoje.senjan@gmail.com
- Update to 4.97.0:
  * Buildsystem fixes
  * For more details please see:
    http://www.kde.org/announcements/announce-frameworks5-alpha2.php
* Sat Feb  8 2014 hrvoje.senjan@gmail.com
- Init kiconthemes package
